@@ -99,7 +99,7 @@ public:
 		return CmpNatural(str1.c_str(), str2.c_str());
 	}
 
-	static int CmpNatural(wxChar const* p1, wxChar const* p2)
+	static int CmpNatural(wchar_t const* p1, wchar_t const* p2)
 	{
 		int res = 0;
 		int zeroCount = 0;
@@ -142,7 +142,7 @@ public:
 		return res;         //same length, compare first different digit in the sequence
 	}
 
-	typedef int (* CompareFunction)(const wxString&, const wxString&);
+	typedef int (* CompareFunction)(std::wstring const&, std::wstring const&);
 	static CompareFunction GetCmpFunction(NameSortMode mode)
 	{
 		switch (mode)
@@ -185,7 +185,7 @@ public:
 	typedef Listing List;
 	typedef typename Listing::value_type value_type;
 
-	CFileListCtrlSort(Listing const& listing, enum DirSortMode dirSortMode, enum NameSortMode nameSortMode)
+	CFileListCtrlSort(Listing const& listing, DirSortMode dirSortMode, NameSortMode nameSortMode)
 		: m_listing(listing), m_dirSortMode(dirSortMode), m_nameSortMode(nameSortMode)
 	{
 	}
@@ -542,8 +542,8 @@ protected:
 
 	void InitSort(int optionID); // Has to be called after initializing columns
 	void SortList(int column = -1, int direction = -1, bool updateSelections = true);
-	enum CFileListCtrlSortBase::DirSortMode GetDirSortMode();
-	enum CFileListCtrlSortBase::NameSortMode GetNameSortMode();
+	CFileListCtrlSortBase::DirSortMode GetDirSortMode();
+	CFileListCtrlSortBase::NameSortMode GetNameSortMode();
 	virtual CSortComparisonObject GetSortComparisonObject() = 0;
 
 	// An empty path denotes a virtual file
@@ -584,6 +584,8 @@ protected:
 #endif
 
 private:
+	void UpdateSelections(int min, int max);
+
 	void SortList_UpdateSelections(bool* selections, int focused_item, unsigned int focused_index);
 
 	// If this is set to true, don't process selection changed events
